@@ -1,19 +1,26 @@
 import typing as t
+from enum import Enum
 
 from pydantic import BaseModel, ConfigDict, Field, field_serializer, field_validator
 from pydantic.json_schema import SkipJsonSchema
 
-from common_py.workflow.nodes.node import ErrorHandling
-from common_py.workflow.nodes.workflow_types import InferenceMode
-from common_py.workflow.utils.pydantic_model_serializer import (
-    deserialize_model,
-    serialize_model,
-)
-
+from ...utils.workflow_utils import ErrorHandling
+from ...utils.pydantic_utils import deserialize_model, serialize_model
 from .. import enums
 from . import ToolOutput
 
 
+class InferenceMode(str, Enum):
+    """
+    Enumeration of inference types.
+    """
+
+    DEFAULT = "DEFAULT"
+    XML = "XML"
+    FUNCTION_CALLING = "FUNCTION_CALLING"
+    STRUCTURED_OUTPUT = "STRUCTURED_OUTPUT"
+
+
 class LLMUsageData(BaseModel):
     prompt_tokens: int
     prompt_tokens_cost_usd: float | None
