@@ -5,6 +5,7 @@ from ..models.tools.datasource_models import (
     CreateDatasourceOutput,
     DeleteDatasourceInput,
     DeleteDatasourceOutput,
+    Enum,
     FieldFormat,
     ReadDatasourcesInput,
     ReadDatasourcesOutput,
@@ -17,6 +18,7 @@ __all__ = [
     "CreateDatasourceOutput",
     "DeleteDatasourceInput",
     "DeleteDatasourceOutput",
+    "Enum",
     "FieldFormat",
     "ReadDatasourcesInput",
     "ReadDatasourcesOutput",
