@@ -1,19 +1,8 @@
 from ..client import A79Client
 from ..models.tools import DEFAULT
-from ..models.tools.outlook_models import (
-    EmailItem,
-    OutlookInput,
-    OutlookOutput,
-    ToolSummary,
-)
+from ..models.tools.outlook_models import EmailItem, OutlookInput, OutlookOutput
 
-__all__ = [
-    "EmailItem",
-    "OutlookInput",
-    "OutlookOutput",
-    "ToolSummary",
-    "fetch_outlook_emails",
-]
+__all__ = ["EmailItem", "OutlookInput", "OutlookOutput", "fetch_outlook_emails"]
 
 
 def fetch_outlook_emails(
