@@ -1,8 +1,8 @@
 from typing import Any
 
-from external.a79.src.a79.client import A79Client
-from external.a79.src.models.tools import DEFAULT
-from external.a79.src.models.tools.workflow_models import (
+from ..client import A79Client
+from ..models.tools import DEFAULT
+from ..models.tools.workflow_models import (
     RunnableResult,
     RunStatus,
     RunWorkflowInput,
